==> hips_hack-0.8.tar.gz: hips_hack-0.8/README.md <==
![banner](https://github.com/Skumbl/hips-hack/blob/main/Screenshot%202023-02-04%20at%2020-19-31%20Modern%20Minimal%20Technology%20Background%20Banner.png)
# H.I.P.S
HIPS or Hidden In Plain Sight is a command line utility that takes in a string and the pathway to a image in order to hide it inside the image bit by bit hidden in random pixels
It is also a web application linked bellow

# Web App (using Flask)
check out the web app here
> nojjktotvrgotyomnz.tech
##### the website name is above, try cracking the cypher to see what it means (not including .tech)

# Install

HIPS is both a web application as well as a pip install terminal package

#### install using pip

    pip3 install hips-hack

this will download the hips utility to your local machine
see **how to use** for the syntax and parameters for the terminal utility

#### download from github
if any of the other methods have gone down for some reason then you can always click this link to install the python package

[download here](https://github.com/Skumbl/hips-hack/blob/main/src/hips_hack/stenography.py)



# How to Use

###  syntax 

(-e )encrypts the message to an image

(-d )decrypts a message from image

( -t )denotes the start of the string being encrypted

< image path > is the local path to the image you are trying to encrypt or decrypt

to encrypt

    python3 -m hips_hack.stenograpghy -e <image path> -t <string to encode>

to decrypt

    python3 -m hips_hack.stenograpghy -d <image path>

the new image with the encryption will be placed 
# How it Works

*TODO WRITE THIS PART*


# Development Team

Dev Team Name - Shadow Wizard Money Gang (we love casting spells)

Jan Arvik - Team Lead / Website Lead

Truman DeWelch- Command line/ PIP developer

Michael Peters - Flask / AWS developer 

Jack Savage - CSS / Typescript Developer

==> hips_hack-0.10.tar.gz: hips_hack-0.10/README.md <==
![banner](https://github.com/Skumbl/hips-hack/blob/main/Screenshot%202023-02-04%20at%2020-19-31%20Modern%20Minimal%20Technology%20Background%20Banner.png)
# H.I.P.S
HIPS or Hidden In Plain Sight is a command line utility that takes in a string and the pathway to a image in order to hide it inside the image bit by bit hidden in random pixels
It is also a web application linked bellow

# Web App (using Flask)
check out the web app here
> nojjktotvrgotyomnz.tech
##### the website name is above, try cracking the cypher to see what it means (not including .tech)

# Install

HIPS is both a web application as well as a pip install terminal package

#### install using pip

    pip3 install hips-hack

this will download the hips utility to your local machine
see **how to use** for the syntax and parameters for the terminal utility

#### download from github
if any of the other methods have gone down for some reason then you can always click this link to install the python package

[download here](https://github.com/Skumbl/hips-hack/blob/main/src/hips_hack/stenography.py)



# How to Use

###  syntax 

(-e )encrypts the message to an image

(-d )decrypts a message from image

( -t )denotes the start of the string being encrypted

< image path > is the local path to the image you are trying to encrypt or decrypt

to encrypt

    python3 -m hips_hack.stenograpghy -e <image path> -t <string to encode>

to decrypt

    python3 -m hips_hack.stenograpghy -d <image path>

the new image with the encryption will be placed 
# How it Works

*TODO WRITE THIS PART*


# Development Team

Dev Team Name - SWMG

Jan Arvik - Team Lead / Website Lead

Truman DeWelch- Command line/ PIP developer

Michael Peters - Flask / AWS developer 

Jack Savage - CSS / Typescript Developer
